
From: Domen Puncer <domen@coderock.org>

When I do a "diff -Nur arch/i386 arch/x86_64" to see what is different between these two
architectures, I see some differences due to whitespace issues only. The attached patch removes
some of the noise by fixing up the following files:
- arch/i386/boot/bootsect.S
- arch/i386/boot/video.S
- arch/x86_64/boot/bootsect.S

Signed-off-by: Daniel Dickman <didickman@yahoo.com>
Signed-off-by: Domen Puncer <domen@coderock.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/i386/boot/bootsect.S   |    2 +-
 25-akpm/arch/i386/boot/video.S      |   18 +++++++++---------
 25-akpm/arch/x86_64/boot/bootsect.S |    4 ++--
 3 files changed, 12 insertions(+), 12 deletions(-)

diff -puN arch/i386/boot/bootsect.S~codingstyle-trivial-whitespace-fixups arch/i386/boot/bootsect.S
--- 25/arch/i386/boot/bootsect.S~codingstyle-trivial-whitespace-fixups	2005-03-19 13:57:25.000000000 -0800
+++ 25-akpm/arch/i386/boot/bootsect.S	2005-03-19 13:57:25.000000000 -0800
@@ -83,7 +83,7 @@ bugger_off_msg:
 	.ascii	"\n"
 	.ascii	"Remove disk and press any key to reboot . . .\r\n"
 	.byte	0
-	
+
 
 	# Kernel attributes; used by setup
 
diff -puN arch/i386/boot/video.S~codingstyle-trivial-whitespace-fixups arch/i386/boot/video.S
--- 25/arch/i386/boot/video.S~codingstyle-trivial-whitespace-fixups	2005-03-19 13:57:25.000000000 -0800
+++ 25-akpm/arch/i386/boot/video.S	2005-03-19 13:57:25.000000000 -0800
@@ -1924,36 +1924,36 @@ skip10:	movb	%ah, %al
 	ret
 
 store_edid:
-	pushw	%es				# just save all registers 
-	pushw	%ax				
+	pushw	%es				# just save all registers
+	pushw	%ax
 	pushw	%bx
 	pushw   %cx
 	pushw	%dx
 	pushw   %di
 
-	pushw	%fs                             
+	pushw	%fs
 	popw    %es
 
 	movl	$0x13131313, %eax		# memset block with 0x13
 	movw    $32, %cx
 	movw	$0x140, %di
 	cld
-	rep 
-	stosl  
+	rep
+	stosl
 
-	movw	$0x4f15, %ax                    # do VBE/DDC 
+	movw	$0x4f15, %ax                    # do VBE/DDC
 	movw	$0x01, %bx
 	movw	$0x00, %cx
 	movw    $0x01, %dx
 	movw	$0x140, %di
-	int	$0x10	
+	int	$0x10
 
-	popw	%di				# restore all registers        
+	popw	%di				# restore all registers
 	popw	%dx
 	popw	%cx
 	popw	%bx
 	popw	%ax
-	popw	%es	
+	popw	%es
 	ret
 
 # VIDEO_SELECT-only variables
diff -puN arch/x86_64/boot/bootsect.S~codingstyle-trivial-whitespace-fixups arch/x86_64/boot/bootsect.S
--- 25/arch/x86_64/boot/bootsect.S~codingstyle-trivial-whitespace-fixups	2005-03-19 13:57:25.000000000 -0800
+++ 25-akpm/arch/x86_64/boot/bootsect.S	2005-03-19 13:57:25.000000000 -0800
@@ -63,7 +63,7 @@ msg_loop:
 	jz	die
 	movb	$0xe, %ah
 	movw	$7, %bx
- 	int	$0x10
+	int	$0x10
 	jmp	msg_loop
 
 die:
@@ -71,7 +71,7 @@ die:
 	xorw	%ax, %ax
 	int	$0x16
 	int	$0x19
-	
+
 	# int 0x19 should never return.  In case it does anyway,
 	# invoke the BIOS reset code...
 	ljmp	$0xf000,$0xfff0
_
